@@ -12,27 +12,45 @@ TEST =      '[TEST   ] '
 
 BACK_SLASH = '\\'
 NEW_LINE = '\n'
-BAR_N = '\\n'
-SPACE = ' '
+BAR_N = f'{BACK_SLASH}n'
 NOTHING = ''
+SPACE = ' '
 SINGLE_QUOTE = "'"
 DOUBLE_QUOTE = '"'
 TRIPLE_SINGLE_QUOTE = f"{3*SINGLE_QUOTE}"
 TRIPLE_DOUBLE_QUOTE = f'{3*DOUBLE_QUOTE}'
+
 BACK_SLASH_SINGLE_QUOTE = "'\'"
 BACK_SLASH_DOUBLE_QUOTE = '\"'
-COMA = ','
-COLON = ':'
 SLASH = '/'
+DOUBLE_SLASH = f'{2*SLASH}'
 HASH_TAG = '#'
-DOT = '.'
 DASH = '-'
-SPACE_DASH_SPACE = ' - '
+SPACE_DASH_SPACE = f'{SPACE}{DASH}{SPACE}'
 UNDERSCORE = '_'
-DOT_SPACE = '. '
-COMA_SPACE = ', '
-COLON_SPACE = ': '
-SPACE_COLON_SPACE = ' : '
+DOLLAR = '$'
+ARROBA = '@'
+AND = '&'
+PLUS = '+'
+EQUALS = '='
+PERCENT = '%'
+
+DOT = '.'
+DOT_SPACE = f'{DOT}{SPACE}'
+COMA = ','
+COMA_SPACE = f'{COMA}{SPACE}'
+COLON = ':'
+COLON_SPACE = f'{COLON}{SPACE}'
+SPACE_COLON_SPACE = f'{SPACE}{COLON}{SPACE}'
+SEMI_COLON = ';'
+SEMI_COLON_SPACE = f'{SEMI_COLON}{SPACE}'
+QUESTION_MARK = '?'
+QUESTION_MARK_SPACE = f'{QUESTION_MARK}{SPACE}'
+EXCLAMATION_MARK = '!'
+EXCLAMATION_MARK_SPACE = f'{EXCLAMATION_MARK}{SPACE}'
+
+
+
 LOG_CAUSE = f'Cause{COLON_SPACE}'
 DOT_SPACE_CAUSE = f'{DOT_SPACE}{LOG_CAUSE}'
 
